import React from 'react';
import PropTypes from 'prop-types';

import TextLabel from '../TextLabel/TextLabel';
import TextField from '../TextField/TextField';
import Switch from '../Toggle/Toggle';
import Button from '../Button/Button';

import getStyles from './SettingsForm.styles';

const SettingsForm = (props) => {
    const {
        contextStyles,
        errors,
        isSaving,
        onCancelPress,
        onSavePress,
        onServerChange,
        onTenantChange,
        onUseOAuthChange,
        onUseServerChange,
        server,
        tenant,
        useOAuth,
        useServer,
    } = props;

    const styles = getStyles(contextStyles);

    return (
        <div style={ styles.container }>
            <h2 style={ styles.heading }>Settings</h2>

            <div style={ styles.tenantContainer }>
                <TextLabel>Tenant ID</TextLabel>
                <TextField
                    onChange={ onTenantChange }
                    value={ tenant }
                    autoFocus />
                { errors && errors['tenant'] &&
                    <TextLabel
                        error
                        contextStyles={ {
                            container: styles.error,
                        } }>
                        { errors['tenant'] }
                    </TextLabel>
                }
            </div>

            <div style={ styles.serverContainer }>
                <TextLabel>Server URL</TextLabel>
                <TextField
                    disabled={ !useServer }
                    onChange={ onServerChange }
                    value={ server } />
                { errors && errors['server'] &&
                    <TextLabel
                        error
                        contextStyles={ {
                            container: styles.error,
                        } }>
                        { errors['server'] }
                    </TextLabel>
                }
            </div>

            <div style={ styles.useOAuthContainer }>
                <Switch
                    checked={ useOAuth }
                    onChange={ onUseOAuthChange } />
                <TextLabel>Use OAuth</TextLabel>
            </div>

            <div style={ styles.useServerContainer }>
                <Switch
                    checked={ useServer }
                    onChange={ onUseServerChange } />
                <TextLabel>Use Server</TextLabel>
            </div>

            { errors && errors['main'] &&
                <TextLabel
                    error
                    contextStyles={ {
                        container: styles.error,
                    } }>
                    { errors['main'] }
                </TextLabel>
            }
            <div style={ styles.buttonContainer }>
                <Button
                    contextStyles={ {
                        container: styles.button,
                        text: styles.buttonText,
                    } }
                    onClick={ onSavePress }
                    disabled={ isSaving || !!(tenant && !tenant.trim()) }
                    text="Save" />
                <Button
                    contextStyles={ {
                        container: styles.button,
                        text: styles.buttonText,
                    } }
                    onClick={ onCancelPress }
                    disabled={ isSaving }
                    text="Cancel" />
            </div>
        </div>
    );
};

SettingsForm.propTypes = {
    contextStyles: PropTypes.shape({
        container: PropTypes.object,
        heading: PropTypes.object,
    }),
    errors: PropTypes.shape({
        main: PropTypes.string,
        tenant: PropTypes.string,
        server: PropTypes.string,
    }),
    isSaving: PropTypes.bool,
    onCancelPress: PropTypes.func.isRequired,
    onSavePress: PropTypes.func.isRequired,
    onServerChange: PropTypes.func.isRequired,
    onTenantChange: PropTypes.func.isRequired,
    onUseOAuthChange: PropTypes.func.isRequired,
    onUseServerChange: PropTypes.func.isRequired,
    server: PropTypes.string.isRequired,
    tenant: PropTypes.string.isRequired,
    useOAuth: PropTypes.bool.isRequired,
    useServer: PropTypes.bool.isRequired,
};

SettingsForm.defaultProps = {
    contextStyles: {},
};

export default SettingsForm;
